<?php
if ( ! function_exists( 'popular_ecommerce_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	*/
	function popular_ecommerce_setup() {
		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 */
		add_theme_support( 'title-tag' );
		add_theme_support( "wp-block-styles" );
		add_theme_support( "responsive-embeds" );
		add_theme_support( "align-wide" );
	}
endif;
add_action( 'after_setup_theme', 'popular_ecommerce_setup' );
/**
 * Dequeue parent theme style and scripts
 *
 * Hooked to the wp_print_scripts action, with a late priority (100),
 * so that it is after the script was enqueued.
 * @package ostore-child
 */
function popular_ecommerce_enqueue_scripts() {
	//remove css from parent
   wp_dequeue_style( 'ostore-main-style' );
   wp_dequeue_script( 'single-product-zoom-js' );

   //Theme Version Check 
		$popular_ecommerce_var = wp_get_theme();
		$theme_version = $popular_ecommerce_var->get( 'Version' );

   //Google Fonts Enqueue
    $popular_ecommerce_google_fonts_list = array('Dosis','Poppins');
    foreach(  $popular_ecommerce_google_fonts_list as $google_font ){
        wp_enqueue_style( 'google-fonts-'.$google_font, '//fonts.googleapis.com/css?family='.$google_font.':300italic,400italic,700italic,400,700,300', false ); 
    }

   /*THEME JS */
   	wp_enqueue_script( 'sidebar-nav', get_theme_file_uri( '/assets/js/sidenav.min.js' ),$theme_version, '', true );
    wp_enqueue_script( 'popular-ecommerce', get_theme_file_uri( '/assets/js/popular-ecommerce.js' ),$theme_version, '', true );

}
add_action( 'wp_enqueue_scripts', 'popular_ecommerce_enqueue_scripts', 100 );


//Add the menu
add_action( 'init', 'popular_ecommerce_store_footer_menu' );
function popular_ecommerce_store_footer_menu() {
    register_nav_menu( 'footer-menu',esc_html__( 'Footer Menu','popular-ecommerce' ) );
}


//Add the submenu class
function my_nav_menu_submenu_css_class( $classes ) {
    $classes[] = 'sidenav-dropdown';
    return $classes;
}
add_filter( 'nav_menu_submenu_css_class', 'my_nav_menu_submenu_css_class' );


/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function popular_ecommerce_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
    }
    
    if( get_theme_mod('ostore_layout_style','box-layout') == 'box-layout' ){
        $classes[] = 'popular-ecommerce-theme-box-layout';
    }

	return $classes;
}
add_filter( 'body_class', 'popular_ecommerce_body_classes' );


/*
* Require Popular eCommerce child theme file
*/
require get_stylesheet_directory() . '/themerelic/extras.php';
require get_stylesheet_directory() . '/themerelic/customizer-control/custom-control.php';
require get_stylesheet_directory() . '/themerelic/popular-ecommerce-customizer.php';